==> lush-0.99_2.tbz: share/lush/include/lushmake.h <==
/***********************************************************************
 * 
 *  LUSH Lisp Universal Shell
 *    Copyright (C) 2002 Leon Bottou, Yann Le Cun, AT&T Corp, NECI.
 *  Includes parts of TL3:
 *    Copyright (C) 1987-1999 Leon Bottou and Neuristique.
 *  Includes selected parts of SN3.2:
 *    Copyright (C) 1991-2001 AT&T Corp.
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA
 * 
 ***********************************************************************/

/***********************************************************************
 * $Id: lushmake.h.in,v 1.2 2003/01/28 18:00:15 leonb Exp $
 **********************************************************************/

#define LUSH_MAKE_MACROS \
  { "SHELL", "/bin/sh" }, \
  { "OPTS", "-DNO_DEBUG  " }, \
  { "DEFS", "-DHAVE_CONFIG_H" }, \
  { "LIBS", "-lreadline -lcurses -lutil -lm  -pthread -lintl -L/usr/local/lib" }, \
  { "host", "amd64-portbld-freebsd5.4" }, \
  { "CPP", "cc -E" }, \
  { "CPPFLAGS", " -I/usr/local/include" }, \
  { "CC", "cc" }, \
  { "GCC", "yes" }, \
  { "CFLAGS", " -pipe" }, \
  { "CXX", "c++" }, \
  { "CXXFLAGS", "-O -pipe" }, \
  { "F77", "f77" }, \
  { "FFLAGS", "-g -O2" }, \
  { "LDCC", "c++" }, \
  { "LDFLAGS", "" }, \
  { "PTHREAD_FLAGS", "-D_THREAD_SAFE " }, \
  { "PTHREAD_LIBS", "" }, \
  { "AR", "/usr/bin/ar" }, \
  { "MV", "/bin/mv" }, \
  { "CP", "/bin/cp" }, \
  { "INDENT", "" }, \
  { "LN_S", "ln -s" }, \
  { "TOUCH", "/usr/bin/touch" }, \
  { "RANLIB", "ranlib" }, \
  { "X_LIBS", "-L/usr/X11R6/lib  -lSM -lICE -lX11 " }, \
  { "X_CFLAGS", "-I/usr/X11R6/include" }, \
  { "CC_PIC_FLAG", "-fPIC" }, \
  { "CC_EXP_FLAG", "" }, \
  { "MAKESO", "cc -shared -o" }, \
  { "EXEEXT", "" }, \
  { "OBJEXT", "o" }, \
  { "SOEXT", "so" }

==> lush-0.99_3.tbz: share/lush/include/lushmake.h <==
/***********************************************************************
 * 
 *  LUSH Lisp Universal Shell
 *    Copyright (C) 2002 Leon Bottou, Yann Le Cun, AT&T Corp, NECI.
 *  Includes parts of TL3:
 *    Copyright (C) 1987-1999 Leon Bottou and Neuristique.
 *  Includes selected parts of SN3.2:
 *    Copyright (C) 1991-2001 AT&T Corp.
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA
 * 
 ***********************************************************************/

/***********************************************************************
 * $Id: lushmake.h.in,v 1.2 2003/01/28 18:00:15 leonb Exp $
 **********************************************************************/

#define LUSH_MAKE_MACROS \
  { "SHELL", "/bin/sh" }, \
  { "OPTS", "-DNO_DEBUG   -pipe" }, \
  { "DEFS", "-DHAVE_CONFIG_H" }, \
  { "LIBS", "-lreadline -lcurses -lutil -lm  -pthread -lintl -L/usr/local/lib" }, \
  { "host", "i386-portbld-freebsd6.2" }, \
  { "CPP", "cc -E" }, \
  { "CPPFLAGS", " -I/usr/local/include" }, \
  { "CC", "cc" }, \
  { "GCC", "yes" }, \
  { "CFLAGS", " -fno-strict-aliasing -pipe" }, \
  { "CXX", "c++" }, \
  { "CXXFLAGS", "-O2 -fno-strict-aliasing -pipe" }, \
  { "F77", "f77" }, \
  { "FFLAGS", "-g -O2" }, \
  { "LDCC", "c++" }, \
  { "LDFLAGS", "" }, \
  { "PTHREAD_FLAGS", "-D_THREAD_SAFE " }, \
  { "PTHREAD_LIBS", "" }, \
  { "AR", "/usr/bin/ar" }, \
  { "MV", "/bin/mv" }, \
  { "CP", "/bin/cp" }, \
  { "INDENT", "" }, \
  { "LN_S", "ln -s" }, \
  { "TOUCH", "/usr/bin/touch" }, \
  { "RANLIB", "ranlib" }, \
  { "X_LIBS", "-L/usr/X11R6/lib  -lSM -lICE -lX11 " }, \
  { "X_CFLAGS", "-I/usr/X11R6/include" }, \
  { "CC_PIC_FLAG", "-fPIC" }, \
  { "CC_EXP_FLAG", "" }, \
  { "MAKESO", "cc -shared -o" }, \
  { "EXEEXT", "" }, \
  { "OBJEXT", "o" }, \
  { "SOEXT", "so" }
